@@ -5,9 +5,9 @@ app_name = 'admin_honeypot'
 
 urlpatterns = [
     path('login/', views.AdminHoneypot.as_view(), name='login'),
-    path('login_sqli/', views.AdminHoneypotSQLi.as_view(), name='login_sqli'),
+    path('login2/', views.AdminHoneypotSQLi.as_view(), name='login_sqli'),
     path('hashcash_metadata/', views.hashcash_metadata, name='hashcash_metadata'),
-    path('path_traversal/', views.PathTraversal.as_view(), name='path_traversal'),
+    path('read_files/', views.PathTraversal.as_view(), name='path_traversal'),
     re_path(r'^.*$', views.AdminHoneypot.as_view(), name='index'),
 ]
 
